slepc-3.18.0 2022-10-01
Report Typos and Errors

# FNSetFromOptions

Sets FN options from the options database.

### Synopsis

    #include "slepcfn.h"
    PetscErrorCode FNSetFromOptions(FN fn)

Collective on fn

### Input Parameters

| fn | - the math function context

### Notes

To see all options, run your program with the -help option.

### See Also

FNSetOptionsPrefix()

### Level

beginner

### Location

src/sys/classes/fn/interface/fnbasic.c
Index of all FN routines
Table of Contents for all manual pages
Index of all manual pages